@@ -367,6 +367,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		bean.setTitle(dataset.getTitle());
 		bean.setDescription(dataset.getNotes());
 		bean.setLicense(dataset.getLicenseTitle());
+		//fixing issue overrides the Visibility [#28736]
 		bean.setVisibile(dataset.isPriv());
 
 		long version = 1;
@@ -430,7 +431,8 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		bean.setTitle(dataset.getTitle());
 		bean.setDescription(dataset.getNotes());
 		bean.setLicense(dataset.getLicenseTitle());
-		bean.setVisibile(dataset.isPriv());
+		//fixing issue overrides the Visibility [#28736]
+		bean.setVisibile(!dataset.isPriv());
 
 		long version = 1;
 		try {
